Megatroniki
===========

A simple wiki project that can be extended.

This project aims to allow other developers, or people who wish to store data
in a wiki format to do so easily.

----


This project uses Python, Flask and Jinja2 to create webpages and a directory
structure to store markdown files for each of the webpages.
